==> s3-0.26.0-sources.jar: software/amazon/awscdk/services/s3/PipelineSourceActionProps.java <==
package software.amazon.awscdk.services.s3;

/**
 * Construction properties of the {@link PipelineSourceAction S3 source Action}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:58:46.039Z")
public interface PipelineSourceActionProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.s3.CommonPipelineSourceActionProps {
    /**
     * The Amazon S3 bucket that stores the source code
     */
    software.amazon.awscdk.services.s3.IBucket getBucket();
    /**
     * The Amazon S3 bucket that stores the source code
     */
    void setBucket(final software.amazon.awscdk.services.s3.IBucket value);

    /**
     * @return a {@link Builder} of {@link PipelineSourceActionProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link PipelineSourceActionProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.s3.IBucket _bucket;
        private java.lang.String _bucketKey;
        @javax.annotation.Nullable
        private java.lang.String _outputArtifactName;
        @javax.annotation.Nullable
        private java.lang.Boolean _pollForSourceChanges;
        private java.lang.String _actionName;
        @javax.annotation.Nullable
        private java.lang.Number _runOrder;

        /**
         * Sets the value of Bucket
         * @param value The Amazon S3 bucket that stores the source code
         * @return {@code this}
         */
        public Builder withBucket(final software.amazon.awscdk.services.s3.IBucket value) {
            this._bucket = java.util.Objects.requireNonNull(value, "bucket is required");
            return this;
        }
        /**
         * Sets the value of BucketKey
         * @param value The key within the S3 bucket that stores the source code.
         * @return {@code this}
         */
        public Builder withBucketKey(final java.lang.String value) {
            this._bucketKey = java.util.Objects.requireNonNull(value, "bucketKey is required");
            return this;
        }
        /**
         * Sets the value of OutputArtifactName
         * @param value The name of the source's output artifact. CfnOutput artifacts are used by CodePipeline as
inputs into other actions.
         * @return {@code this}
         */
        public Builder withOutputArtifactName(@javax.annotation.Nullable final java.lang.String value) {
            this._outputArtifactName = value;
            return this;
        }
        /**
         * Sets the value of PollForSourceChanges
         * @param value Whether AWS CodePipeline should poll for source changes.
If this is `false`, the Pipeline will use CloudWatch Events to detect source changes instead.
Note that if this is `false`, you need to make sure to include the source Bucket in a CloudTrail Trail,
as otherwise the CloudWatch Events will not be emitted.
         * @return {@code this}
         */
        public Builder withPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
            this._pollForSourceChanges = value;
            return this;
        }
        /**
         * Sets the value of ActionName
         * @param value The physical, human-readable name of the Action.
Not that Action names must be unique within a single Stage.
         * @return {@code this}
         */
        public Builder withActionName(final java.lang.String value) {
            this._actionName = java.util.Objects.requireNonNull(value, "actionName is required");
            return this;
        }
        /**
         * Sets the value of RunOrder
         * @param value The runOrder property for this Action.
RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @return {@code this}
         */
        public Builder withRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
            this._runOrder = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PipelineSourceActionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public PipelineSourceActionProps build() {
            return new PipelineSourceActionProps() {
                private software.amazon.awscdk.services.s3.IBucket $bucket = java.util.Objects.requireNonNull(_bucket, "bucket is required");
                private java.lang.String $bucketKey = java.util.Objects.requireNonNull(_bucketKey, "bucketKey is required");
                @javax.annotation.Nullable
                private java.lang.String $outputArtifactName = _outputArtifactName;
                @javax.annotation.Nullable
                private java.lang.Boolean $pollForSourceChanges = _pollForSourceChanges;
                private java.lang.String $actionName = java.util.Objects.requireNonNull(_actionName, "actionName is required");
                @javax.annotation.Nullable
                private java.lang.Number $runOrder = _runOrder;

                @Override
                public software.amazon.awscdk.services.s3.IBucket getBucket() {
                    return this.$bucket;
                }

                @Override
                public void setBucket(final software.amazon.awscdk.services.s3.IBucket value) {
                    this.$bucket = java.util.Objects.requireNonNull(value, "bucket is required");
                }

                @Override
                public java.lang.String getBucketKey() {
                    return this.$bucketKey;
                }

                @Override
                public void setBucketKey(final java.lang.String value) {
                    this.$bucketKey = java.util.Objects.requireNonNull(value, "bucketKey is required");
                }

                @Override
                public java.lang.String getOutputArtifactName() {
                    return this.$outputArtifactName;
                }

                @Override
                public void setOutputArtifactName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$outputArtifactName = value;
                }

                @Override
                public java.lang.Boolean getPollForSourceChanges() {
                    return this.$pollForSourceChanges;
                }

                @Override
                public void setPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
                    this.$pollForSourceChanges = value;
                }

                @Override
                public java.lang.String getActionName() {
                    return this.$actionName;
                }

                @Override
                public void setActionName(final java.lang.String value) {
                    this.$actionName = java.util.Objects.requireNonNull(value, "actionName is required");
                }

                @Override
                public java.lang.Number getRunOrder() {
                    return this.$runOrder;
                }

                @Override
                public void setRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
                    this.$runOrder = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.s3.PipelineSourceActionProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The Amazon S3 bucket that stores the source code
         */
        @Override
        public software.amazon.awscdk.services.s3.IBucket getBucket() {
            return this.jsiiGet("bucket", software.amazon.awscdk.services.s3.IBucket.class);
        }

        /**
         * The Amazon S3 bucket that stores the source code
         */
        @Override
        public void setBucket(final software.amazon.awscdk.services.s3.IBucket value) {
            this.jsiiSet("bucket", java.util.Objects.requireNonNull(value, "bucket is required"));
        }

        /**
         * The key within the S3 bucket that stores the source code.
         * @example 'path/to/file.zip'
         */
        @Override
        public java.lang.String getBucketKey() {
            return this.jsiiGet("bucketKey", java.lang.String.class);
        }

        /**
         * The key within the S3 bucket that stores the source code.
         * @example 'path/to/file.zip'
         */
        @Override
        public void setBucketKey(final java.lang.String value) {
            this.jsiiSet("bucketKey", java.util.Objects.requireNonNull(value, "bucketKey is required"));
        }

        /**
         * The name of the source's output artifact. CfnOutput artifacts are used by CodePipeline as
         * inputs into other actions.
         * @default a name will be auto-generated
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.String getOutputArtifactName() {
            return this.jsiiGet("outputArtifactName", java.lang.String.class);
        }

        /**
         * The name of the source's output artifact. CfnOutput artifacts are used by CodePipeline as
         * inputs into other actions.
         * @default a name will be auto-generated
         */
        @Override
        public void setOutputArtifactName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("outputArtifactName", value);
        }

        /**
         * Whether AWS CodePipeline should poll for source changes.
         * If this is `false`, the Pipeline will use CloudWatch Events to detect source changes instead.
         * Note that if this is `false`, you need to make sure to include the source Bucket in a CloudTrail Trail,
         * as otherwise the CloudWatch Events will not be emitted.
         * @default true
         * @see https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/log-s3-data-events.html
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Boolean getPollForSourceChanges() {
            return this.jsiiGet("pollForSourceChanges", java.lang.Boolean.class);
        }

        /**
         * Whether AWS CodePipeline should poll for source changes.
         * If this is `false`, the Pipeline will use CloudWatch Events to detect source changes instead.
         * Note that if this is `false`, you need to make sure to include the source Bucket in a CloudTrail Trail,
         * as otherwise the CloudWatch Events will not be emitted.
         * @default true
         * @see https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/log-s3-data-events.html
         */
        @Override
        public void setPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
            this.jsiiSet("pollForSourceChanges", value);
        }

        /**
         * The physical, human-readable name of the Action.
         * Not that Action names must be unique within a single Stage.
         */
        @Override
        public java.lang.String getActionName() {
            return this.jsiiGet("actionName", java.lang.String.class);
        }

        /**
         * The physical, human-readable name of the Action.
         * Not that Action names must be unique within a single Stage.
         */
        @Override
        public void setActionName(final java.lang.String value) {
            this.jsiiSet("actionName", java.util.Objects.requireNonNull(value, "actionName is required"));
        }

        /**
         * The runOrder property for this Action.
         * RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @default 1
         * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Number getRunOrder() {
            return this.jsiiGet("runOrder", java.lang.Number.class);
        }

        /**
         * The runOrder property for this Action.
         * RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @default 1
         * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html
         */
        @Override
        public void setRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
            this.jsiiSet("runOrder", value);
        }
    }
}

==> s3-0.27.0-sources.jar: software/amazon/awscdk/services/s3/PipelineSourceActionProps.java <==
package software.amazon.awscdk.services.s3;

/**
 * Construction properties of the {@link PipelineSourceAction S3 source Action}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:36:36.892Z")
public interface PipelineSourceActionProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.s3.CommonPipelineSourceActionProps {
    /**
     * The Amazon S3 bucket that stores the source code
     */
    software.amazon.awscdk.services.s3.IBucket getBucket();

    /**
     * @return a {@link Builder} of {@link PipelineSourceActionProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link PipelineSourceActionProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.s3.IBucket _bucket;
        private java.lang.String _bucketKey;
        @javax.annotation.Nullable
        private java.lang.String _outputArtifactName;
        @javax.annotation.Nullable
        private java.lang.Boolean _pollForSourceChanges;
        private java.lang.String _actionName;
        @javax.annotation.Nullable
        private java.lang.Number _runOrder;

        /**
         * Sets the value of Bucket
         * @param value The Amazon S3 bucket that stores the source code
         * @return {@code this}
         */
        public Builder withBucket(final software.amazon.awscdk.services.s3.IBucket value) {
            this._bucket = java.util.Objects.requireNonNull(value, "bucket is required");
            return this;
        }
        /**
         * Sets the value of BucketKey
         * @param value The key within the S3 bucket that stores the source code.
         * @return {@code this}
         */
        public Builder withBucketKey(final java.lang.String value) {
            this._bucketKey = java.util.Objects.requireNonNull(value, "bucketKey is required");
            return this;
        }
        /**
         * Sets the value of OutputArtifactName
         * @param value The name of the source's output artifact. CfnOutput artifacts are used by CodePipeline as
inputs into other actions.
         * @return {@code this}
         */
        public Builder withOutputArtifactName(@javax.annotation.Nullable final java.lang.String value) {
            this._outputArtifactName = value;
            return this;
        }
        /**
         * Sets the value of PollForSourceChanges
         * @param value Whether AWS CodePipeline should poll for source changes.
If this is `false`, the Pipeline will use CloudWatch Events to detect source changes instead.
Note that if this is `false`, you need to make sure to include the source Bucket in a CloudTrail Trail,
as otherwise the CloudWatch Events will not be emitted.
         * @return {@code this}
         */
        public Builder withPollForSourceChanges(@javax.annotation.Nullable final java.lang.Boolean value) {
            this._pollForSourceChanges = value;
            return this;
        }
        /**
         * Sets the value of ActionName
         * @param value The physical, human-readable name of the Action.
Not that Action names must be unique within a single Stage.
         * @return {@code this}
         */
        public Builder withActionName(final java.lang.String value) {
            this._actionName = java.util.Objects.requireNonNull(value, "actionName is required");
            return this;
        }
        /**
         * Sets the value of RunOrder
         * @param value The runOrder property for this Action.
RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @return {@code this}
         */
        public Builder withRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
            this._runOrder = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PipelineSourceActionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public PipelineSourceActionProps build() {
            return new PipelineSourceActionProps() {
                private final software.amazon.awscdk.services.s3.IBucket $bucket = java.util.Objects.requireNonNull(_bucket, "bucket is required");
                private final java.lang.String $bucketKey = java.util.Objects.requireNonNull(_bucketKey, "bucketKey is required");
                @javax.annotation.Nullable
                private final java.lang.String $outputArtifactName = _outputArtifactName;
                @javax.annotation.Nullable
                private final java.lang.Boolean $pollForSourceChanges = _pollForSourceChanges;
                private final java.lang.String $actionName = java.util.Objects.requireNonNull(_actionName, "actionName is required");
                @javax.annotation.Nullable
                private final java.lang.Number $runOrder = _runOrder;

                @Override
                public software.amazon.awscdk.services.s3.IBucket getBucket() {
                    return this.$bucket;
                }

                @Override
                public java.lang.String getBucketKey() {
                    return this.$bucketKey;
                }

                @Override
                public java.lang.String getOutputArtifactName() {
                    return this.$outputArtifactName;
                }

                @Override
                public java.lang.Boolean getPollForSourceChanges() {
                    return this.$pollForSourceChanges;
                }

                @Override
                public java.lang.String getActionName() {
                    return this.$actionName;
                }

                @Override
                public java.lang.Number getRunOrder() {
                    return this.$runOrder;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("bucket", om.valueToTree(this.getBucket()));
                    obj.set("bucketKey", om.valueToTree(this.getBucketKey()));
                    obj.set("outputArtifactName", om.valueToTree(this.getOutputArtifactName()));
                    obj.set("pollForSourceChanges", om.valueToTree(this.getPollForSourceChanges()));
                    obj.set("actionName", om.valueToTree(this.getActionName()));
                    obj.set("runOrder", om.valueToTree(this.getRunOrder()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.s3.PipelineSourceActionProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The Amazon S3 bucket that stores the source code
         */
        @Override
        public software.amazon.awscdk.services.s3.IBucket getBucket() {
            return this.jsiiGet("bucket", software.amazon.awscdk.services.s3.IBucket.class);
        }

        /**
         * The key within the S3 bucket that stores the source code.
         * @example 'path/to/file.zip'
         */
        @Override
        public java.lang.String getBucketKey() {
            return this.jsiiGet("bucketKey", java.lang.String.class);
        }

        /**
         * The name of the source's output artifact. CfnOutput artifacts are used by CodePipeline as
         * inputs into other actions.
         * @default a name will be auto-generated
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.String getOutputArtifactName() {
            return this.jsiiGet("outputArtifactName", java.lang.String.class);
        }

        /**
         * Whether AWS CodePipeline should poll for source changes.
         * If this is `false`, the Pipeline will use CloudWatch Events to detect source changes instead.
         * Note that if this is `false`, you need to make sure to include the source Bucket in a CloudTrail Trail,
         * as otherwise the CloudWatch Events will not be emitted.
         * @default true
         * @see https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/log-s3-data-events.html
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Boolean getPollForSourceChanges() {
            return this.jsiiGet("pollForSourceChanges", java.lang.Boolean.class);
        }

        /**
         * The physical, human-readable name of the Action.
         * Not that Action names must be unique within a single Stage.
         */
        @Override
        public java.lang.String getActionName() {
            return this.jsiiGet("actionName", java.lang.String.class);
        }

        /**
         * The runOrder property for this Action.
         * RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @default 1
         * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Number getRunOrder() {
            return this.jsiiGet("runOrder", java.lang.Number.class);
        }
    }
}
